#
# spec file for package python-ncclient
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without test
Name:           python-ncclient
Version:        0.6.3
Release:        22.1
Summary:        Python library for NETCONF clients
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://ncclient.org
Source:         https://files.pythonhosted.org/packages/source/n/ncclient/ncclient-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-lxml >= 3.3.0
Requires:       python-paramiko >= 1.15.0
Requires:       python-selectors2 >= 2.0.1
Requires:       python-setuptools > 0.6
Requires:       python-six
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module lxml >= 3.3.0}
BuildRequires:  %{python_module paramiko >= 1.15.0}
BuildRequires:  %{python_module setuptools > 0.6}
BuildRequires:  %{python_module six}
%endif
%python_subpackages

%description
ncclient is a Python library that facilitates client-side scripting
and application development around the NETCONF protocol.

%package -n python-ncclient-doc
Summary:        Python NETCONF protocol library - Documentation
Group:          Documentation/HTML
BuildRequires:  %{python_module Sphinx}
Provides:       %{python_module python-ncclient-doc = %{version}}

%description -n python-ncclient-doc
This package contains documentation files for %{name}.

%prep
%setup -q -n ncclient-%{version}

%build
%python_build
cd docs && make %{?_smp_mflags} html && rm build/html/.buildinfo

%install
%python_install
%fdupes %{buildroot}

%files %{python_files}
%license LICENSE
%{python_sitelib}/*

%files -n python-ncclient-doc
%doc README README.rst examples docs/build/html

%changelog
* Wed Mar 20 2019 tbechtold@suse.com
- update to version v0.6.3
  * Housekeeping & Cleaning
  * Log sent and received messages at level INFO. Fixes #167
  * - move known_hosts_lookup (the host entry in known_hosts, with optional port number appended)
  * First draft of versioning with versioneer (#269)
  * revert to raising SSHError
  * fix: add missing placeholder in exception string
  * Updates to re-enable Python 3.7 (#249)
  * Updates for 0.5.4 and 0.6.0
  * SSH Host key checking (#280)
  * check for transform_reply type (#270)
  * Change superclass call style to keep tests happy
  * SSH Host key checking
  * Fix homepage link registered with PyPi (#274)
  * more tests
  * invoke self.parse() to ensure errors, if any, have been detetcted before check in ok() (#286)
  * Avoid spurious SessionCloseError when intentionally closing session. (#268)
  * Minor edits
  * Revert "Fixes to unit tests to account for use of selectors"
  * Close the channel when closing SSH session
  * Revert "fixes to tests for python2.7"
  * add Huawei device support through YANG (#1) (#242)
  * Revert "use selectors instead of select; improve performance of base 1.0 or 1.1 selection"
  * instructions for running unit tests locally
  * updated README.md in preparation for 0.6.1 release
  * netconf:base:1.1 parsing improvements (#267)
  * Add session as extra context to session-related logs
  * Include host in log message as well, as session-id is not globally unique
  * fix: comments & whitespace tidy
  * removed Manager class metaclass and modified operation lookup to __getattr__ (#200)
  * Add support for loading host-specific known_hosts files via UserKnownHostsFile. (#255)
  * Typo in log message
  * selector changes (#260)
  * use selectors instead of select; improve performance of base 1.0 or 1.1 selection
  * Updated junos.py to resolve RestrictedUser error: (#283)
  * change hostkey var name to be explicit on type hostkey_b64
  * Fixes to unit tests to account for use of selectors
  * fixes to tests for python2.7
  * remove breaking test for incorrect host key padding
  * check known_hosts only if hostkey_b64 not specified
  * include selectors2 in requirements
  * remove unused import
  * Revert "include selectors2 in requirements"
- Drop pr-109.patch
* Sat Sep  8 2018 dmueller@suse.com
- Update to 0.5.4
  * Python 3.6 support
* Mon Aug  7 2017 mardnh@gmx.de
- Update to 0.5.3
  * Add notifications support
  * Add support for ecdsa keys
  * Various bug fixes
- Convert to singlespec
- Rebase patch: pr-109.patch
* Sat Sep  3 2016 mardnh@gmx.de
- update to 0.5.2:
  * Add support for Python 3
  * Improve Junos ioproc performance
  * Performance improvements
  * Updated test cases
  * Many bug and performance fixes
- fix source-url
- rebase patch: pr-109.patch
* Fri Feb  5 2016 tbechtold@suse.com
- switch to version from pypi
  This is the version used by OpenStack networking-cisco
- update to 0.4.7:
  * Add support for netconf 1.1
  * Fix multiple RPC error handling
  * Add support for cancel-commit and persist param
  * Add more examples
  * Add Huawei device support
  * Add cli command support for hpcomware v7 devices
  * Add H3C support, Support H3C CLI,Action,Get_bulk,Save,Rollback,etc.
  * Add alcatel lucent support
  * Rewrite multiple error handling
  * Add coveralls support, with shield in README.md
  * Set severity level to higher when multiple
  * Simplify logging and multi-error reporting
  * Keep stacktrace of errors
  * Check for known hosts on hostkey_verify only
  * Add check for device sending back null error_text
  * Fix RPC.raise_mode
  * Specifying hostkey_verify=False should not load_known_hosts
  * Check the correct field on rpc-error element
  * Nexus exec_command operation
  * Allow specifying multiple cmd elements in Cisco Nexus
  * Update rpc for nested rpc-errors
  * Prevent race condition in threading
  * Prevent hanging in session close
  * Support for paramiko ProxyCommand via ~/.ssh/config parsing
  * Add Juniper-specific commit operations
  * Add Huawei devices support
  * Tests/Travis support
  * ioproc transport support for Juniper devices
  * Update Cisco CSR device handler
  * Fix issue with locked method missing device handler
  * Fix for namespace definition with lxml
  * Add missing SessionError exception
  * Update docs for Nexus device handler
  * Docstring fixes
  * Typos
  * Minor bugfixes
  * Add an example for Cisco CSR1000v
- Remove nexus-support.patch . Applied upstream.
- Adjust Requires according to requirements.txt
- Split documentation into extra -doc package
- Add pr-109.patch . This lowers the lxml requirement so this
  package works with SLE12.
- Stop using openstack-suse-macros for now. This fixes the build
  for openSUSE 13.2 and SLE11SP3
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file. Use fedora compatible files macros
* Mon Aug 26 2013 rhafer@suse.com
- added nexus-support.patch: this is required to make make ncclient
  capable of accessing cisco nexus switches (for quantum's nexus
  plugin)
* Thu Aug  8 2013 dmueller@suse.com
- (rpm-wise) downgrade to a released version 0.3.2:
  * http://ncclient.grnet.gr/0.3.2/
* Mon Jul 29 2013 speilicke@suse.com
- Require python-paramiko (for ssh transport)
- Build HTML documentation
